@@ -10,17 +10,17 @@ FUNCTION = function (f, ..., call)
 
 is.FUNCTION = function (f) inherits (f, "FUNCTION")
 
-#could cause infinite recursion
-#cloning regular functions with environments?
-clone.FUNCTION = function (f, ...)
-{	g = f
-	environment (g) = clone (environment (f) )
-	g
-}
-
-"$.FUNCTION" = function (f, name) get (name, environment (f) )
-"$<-.FUNCTION" = function (f, name, value)
-{	assign (name, value, environment (f) )
+definef = function (f, def, ...)
+{	b = NULL
+	n = length (def)
+	if (n == 1) b = parse (text=def)
+	else if (n > 1)
+	{	b = list ()
+		b [[1]] = as.name ("{")
+		for (i in 1:n) b [[i + 1]] = parse (text=def [i]) [[1]]
+		b = as.call (b)
+	}
+	body (f) = b
 	f
 }
 
@@ -37,6 +37,21 @@ extendf = function (f, subclass, g, ..., attributes)
 	extend (f, subclass, attributes=attributes)
 }
 
+
+#could cause infinite recursion
+#cloning regular functions with environments?
+clone.FUNCTION = function (f, ...)
+{	g = f
+	environment (g) = clone (environment (f) )
+	g
+}
+
+"$.FUNCTION" = function (f, name) get (name, environment (f) )
+"$<-.FUNCTION" = function (f, name, value)
+{	assign (name, value, environment (f) )
+	f
+}
+
 print.FUNCTION = function (f, ...)
 {	g = format (args (f) )
 	n = length (g)
@@ -53,5 +68,3 @@ print.FUNCTION = function (f, ...)
 }
 
 
-
-
